package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````)"````````!``````````$"A````
M`````````$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````'R/````````?(\`````````
M``$```````$````&````@)L```````"`FP$``````(";`0``````^`0`````
M``!0%0```````````0```````@````8```"0FP```````)";`0``````D)L!
M``````#@`0```````.`!````````"`````````!0Y71D!````'B)````````
M>(D```````!XB0```````/0`````````]``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```"`FP```````(";`0``````@)L!``````"`!```````
M`(`$`````````0`````````O;&EB+VQD+6UU<VPM86%R8V@V-"YS;RXQ````
M`````!$```!.````!`````@````A$!``!<`$@"@`$`6`AD"$@B$`!`D`!(F(
M@!A!N@0""$X```!/````4P```%@```!9````8````&$```!B`````````&0`
M``!E`````````&8```!G````:@```````````````:\TZ&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'QV5#R4(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'
MXD?&`5COEWF[XY)\5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````````````````P`'`#@:
M`````````````````````````P`2``"@`0`````````````````,````$@``
M``````````````````````#:`0``$@`````````````````````````4````
M$0```````````````````````````@``$0````````````````````````!\
M`0``$@`````````````````````````;````$@``````````````````````
M``"Y`0``$@`````````````````````````C````$@``````````````````
M```````J````$@`````````````````````````-`@``$@``````````````
M``````````#%`0``$@`````````````````````````S````(```````````
M``````````````!!`P``(0````````````````````````!+````$@``````
M``````````````````!1````$@````````````````````````!8````$@``
M```````````````````````.`P``$@````````````````````````#_`@``
M$@````````````````````````"2`@``$@````````````````````````!?
M````$@`````````````````````````S`@``$@``````````````````````
M``!F````$@````````````````````````#'`@``$@``````````````````
M``````!M````$@````````````````````````!U````$@``````````````
M``````````"P`@``$@````````````````````````!]````$@``````````
M``````````````"#````$@````````````````````````",````(```````
M``````````````````#X`@``$@````````````````````````"H````$@``
M``````````````````````"M````$@`````````````````````````>`@``
M$0````````````````````````#.`@``$@````````````````````````!@
M`@``$@````````````````````````"T````$@``````````````````````
M``!2`@``$@````````````````````````!E`P``$@``````````````````
M``````!``P``$0````````````````````````"$`@``$@``````````````
M```````````M`P``$@````````````````````````!"`P``$0``````````
M``````````````"[````$@`````````````````````````E`P``$@``````
M``````````````````#$````$0````````````````````````"*`0``$@``
M``````````````````````#6````(@````````````````````````#E````
M(`````````````````````````#[````$@````````````````````````#P
M`@``$@````````````````````````!P`@``$@``````````````````````
M`````0``$@`````````````````````````&`0``(```````````````````
M``````"[`@``$@`````````````````````````@`0``$@``````````````
M``````````"J`0``$@`````````````````````````E`0``$@``````````
M``````````````"@`@``$@````````````````````````"9`0``$@``````
M```````````````````K`0``$@`````````````````````````\`0``$@``
M```````````````````````N`@``$@````````````````````````!^````
M$@`````````````````````````_`@``$@````````````````````````!Y
M`@``$@`````````````````````````>`P``$@``````````````````````
M``!"`0``$@`````````````````````````6`P``$@``````````````````
M``````!6`0``$@`````````````````````````I`@``$@``````````````
M``````````#H`0``$@````````````````````````!=`0``$@``````````
M``````````````!D`0``$@`````````````````````````_`P``(0``````
M``````````````````!U`0``$@````````````````````````!E!```$``3
M`-"P`0`````````````````Z`P``$@`)`%`>````````U`$```````#Z`0``
M$@`*`"!,````````!`````````"G`P``$@`)`$`N````````Z`4```````!U
M!```$@`)`'@W````````9`````````"$`P``$@`)`'0H````````!```````
M```9!```$@`'`#@:````````!`````````#*`P``$@`)`"@T````````4`,`
M```````?!```$``3`'B@`0````````````````!-!```$@`)`'@H````````
MT`$````````"!```$``3`'B@`0````````````````"5`P``$@`)`(PM````
M````M`````````"T`P``$@`)`+@F````````.`````````"\`P``$@`)`!0M
M````````6`````````#@`P``$@`)`!Q)````````<`$```````#U`P``$@`)
M`$@J````````)``````````.!```$``3`-"P`0````````````````!P!```
M$``3`-"P`0````````````````!*`P``$@`)`$`@````````,``````````M
M!```$@`)`&PJ``````````$```````#K`P``$0`2`'"@`0``````"```````
M``!&!```$``2`'B@`0`````````````````'!```$@`)`"0@````````````
M```````6!```$@`)`,!(````````7`````````!3`P``$@`)`&PM````````
M(`````````!N`P``$@`)`$0G````````,`$```````!:!```$@`)`(Q*````
M````E`$```````!D!```$``3`-"P`0`````````````````Y!```$@`)`&PK
M````````J`$`````````;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L
M;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L
M<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N
M8VUP`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A
M<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`
M8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?
M97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC
M<'D`<W1R;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%]F:6YI`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R
M;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A
M9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L:6)C+FUU<VPM86%R8V@V-"YS;RXQ
M`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT
M9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N
M`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P
M871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E
M;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?8G-S7W-T87)T
M7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R
M;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S
M<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``(";`0```````P0````````\
M(0```````(B;`0```````P0```````#4(````````("?`0```````P0`````
M``!0'@```````)B?`0```````P0````````@3````````+"?`0```````P0`
M```````X&@````````"@`0```````P0`````````H`$``````!"@`0``````
M`P0````````23P```````!B@`0```````P0```````!=3````````"B@`0``
M`````P0````````^30```````#"@`0```````P0````````W30```````#B@
M`0```````P0````````&3P```````$"@`0```````P0```````!430``````
M`$B@`0```````P0````````.3P```````%B@`0```````P0```````#X3@``
M`````&"@`0```````P0```````#]3@```````'"@`0```````P0````````7
M3P```````(B?`0```````00```4``````````````)"?`0```````00```8`
M`````````````*"?`0```````00```X``````````````*B?`0```````00`
M`!\``````````````+B?`0```````00``",``````````````,"?`0``````
M`00``"P``````````````,B?`0```````00``"\``````````````-"?`0``
M`````00``#$``````````````-B?`0```````00``#(``````````````."?
M`0```````00``#<``````````````.B?`0```````00``#P`````````````
M`/"?`0```````00``#T``````````````/B?`0```````00``$(`````````
M`````(B=`0```````@0```,``````````````)"=`0```````@0```0`````
M`````````)B=`0```````@0```<``````````````*"=`0```````@0```@`
M`````````````*B=`0```````@0```D``````````````+"=`0```````@0`
M``H``````````````+B=`0```````@0```L``````````````,"=`0``````
M`@0```P``````````````,B=`0```````@0```T``````````````-"=`0``
M`````@0```X``````````````-B=`0```````@0``!```````````````."=
M`0```````@0``!$``````````````.B=`0```````@0``!(`````````````
M`/"=`0```````@0``!,``````````````/B=`0```````@0``!0`````````
M``````">`0```````@0``!4```````````````B>`0```````@0``!8`````
M`````````!">`0```````@0``!<``````````````!B>`0```````@0``!@`
M`````````````"">`0```````@0``!D``````````````"B>`0```````@0`
M`!H``````````````#">`0```````@0``!L``````````````#B>`0``````
M`@0``!P``````````````$">`0```````@0``!T``````````````$B>`0``
M`````@0``!X``````````````%">`0```````@0``"```````````````%B>
M`0```````@0``"$``````````````&">`0```````@0``"(`````````````
M`&B>`0```````@0``"0``````````````'">`0```````@0``"4`````````
M`````'B>`0```````@0``"8``````````````(">`0```````@0``"<`````
M`````````(B>`0```````@0``"@``````````````)">`0```````@0``"H`
M`````````````)B>`0```````@0``"L``````````````*">`0```````@0`
M`"T``````````````*B>`0```````@0``"X``````````````+">`0``````
M`@0``#```````````````+B>`0```````@0``#$``````````````,">`0``
M`````@0``#(``````````````,B>`0```````@0``#,``````````````-">
M`0```````@0``#0``````````````-B>`0```````@0``#4`````````````
M`.">`0```````@0``#8``````````````.B>`0```````@0``#@`````````
M`````/">`0```````@0``#D``````````````/B>`0```````@0``#H`````
M``````````"?`0```````@0``#L```````````````B?`0```````@0``#X`
M`````````````!"?`0```````@0``#\``````````````!B?`0```````@0`
M`$```````````````""?`0```````@0``$$``````````````"B?`0``````
M`@0``$,``````````````#"?`0```````@0``$0``````````````#B?`0``
M`````@0``$4``````````````$"?`0```````@0``$8``````````````$B?
M`0```````@0``$<``````````````%"?`0```````@0``$@`````````````
M`%B?`0```````@0``$D``````````````&"?`0```````@0``$H`````````
M`````&B?`0```````@0``$L``````````````'"?`0```````@0``$T`````
M`````````/U[OZG]`P"1_7O!J,`#7]8``````````/![OZG0``"0$<)&^1`"
M-I$@`A_6'R`#U1\@`]4?(`/5T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(V
MD2`"'];0``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y
M$*(VD2`"'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1
MXD;Y$`(WD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM``
M`)`1[D;Y$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?
MUM```)`1^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1
M(`(?UM```)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D0
M8CB1(`(?UM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:
M1_D0PCB1(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```
MD!$F1_D0(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6
MT```D!$R1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@
M`A_6T```D!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B
M.I$@`A_6T```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'
M^1"".I$@`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0
M$5Y'^1#B.I$@`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0
M``"0$6I'^1!".Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"
M'];0``"0$79'^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([
MD2`"'];0``"0$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y
M$$(\D2`"'];0``"0$8Y'^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1
MED?Y$*(\D2`"'];0``"0$9I'^1#"/)$@`A_6T```D!&>1_D0XCR1(`(?UM``
M`)`1HD?Y$`(]D2`"'];0``"0$:9'^1`B/9$@`A_6T```D!&J1_D00CV1(`(?
MUM```)`1KD?Y$&(]D2`"'];0``"0$;)'^1""/9$@`A_6T```D!&V1_D0HCV1
M(`(?UM```)`1ND?Y$,(]D2`"'];]>[NI_0,`D?-3`:G3``"PU```D/43`/GB
MAP.IXN,`D>$#`9'@3P"YX#,!D9'__Y?"``"0P```D$+\1_D`^$?YX0,"JB__
M_Y?```"0`,A'^0``0#F``0`U8O__EV+"`I%`#`#Y8```M2``@%*-__^7I/__
MEX#>1_D``$"YP?__EQ_$*#F4WD?Y@`)`N;W__Y<!:%(Y(0`?,@%H$CF``D"Y
MN/__EP%H4CDA```R`6@2.>!/0+D`%``1`'Q]DXG__Y?E(T#Y8L("D>0`@)*A
M`$#Y`0``^0$``/`AR#N1`00`^<$``+!`!`#Y(3A`^0$(`/D!``#P(=0[D0$,
M`/F!`(!2000`N0$`@-+B3T"Y(00`D5\``6ML!0!401``$77"`I'C`P"J0@P`
M$8',(8L$`(#2'V@A^`$``+"@#D#Y(<`;D1#__Y?T`P`J@```-:`.0/E<__^7
M]`,`*G7"`I&@#D#Y-/__EP```/``Q#.1FP``E&`!`+6@"D#YH```M0```/``
MF#*1E0``E*`*`/E@P@*1``A`^4```+3D!0"4<\("D6`.0/F#__^7IO[_E^`#
M%"KS4T&I]1-`^?U[Q:C``U_6(Q``$:9X8?B#S".+!F@C^,___Q<=`(#2'@"`
MTN`#`)&A``#P(4`ND1_L?)(!```4_7N_J:0``/"C``#P_0,`D0&$0/@%`(#2
MA,Q'^>(#`*J@``#P8]A'^0#`1_D)__^7P```D`#@`9'!``"0(>`!D3\``.N@
M``!4H0``\"'41_E!``"T(``?UL`#7];```"0`.`!D<$``)`AX`&1(0``RT(`
M@-(A_$.3(0S"FJ$``+2B``#P0O!'^4(``+1``!_6P`-?UL```)`!X$$YX0(`
M-?U[OJG]`P"1\PL`^?,#`*J@``#P`.A'^8```+3```"0``!`^?/^_Y?:__^7
MH```\`#01_F```"T(```T`#`*9%X_O^7(`"`4F#B`3GS"T#Y_7O"J,`#7];`
M`U_6H```\`#L1_D@`0"T_7N_J<$``)`@``#0_0,`D2$``I$`P"F1X/[_E_U[
MP:C-__\7_7N\J?T#`)'S4P&I]5L"J?=C`ZD`!0"TH@``\$+@1_E7`$#YEP0`
MM.(#`*I#`$`Y?_0`<6080'IA`P!40@``2_@#`:KV`P"J]0,7JE-\0).T`D#Y
MU`$`M.(#$ZKA`Q:JX`,4JGS^_Y<@`@`U@&IS.!_T`''!`0!4M0(7RW,&`)&4
M`A.+M?Y#DQ4#`+G@`Q2J\U-!J?5;0JGW8T.I_7O$J,`#7]9"!`"1X?__%[4B
M`)'H__\7%`"`TO7__Q?]>[VI_0,`D?,+`/FS``#P<^9'^6$"0/GA%P#Y`0"`
MTN&3`)'(__^7XA=`^6$"0/E!``'*00``M/3^_Y?S"T#Y_7O#J,`#7];]>[RI
M_0,`D?5;`JGU`P"JH```\/-3`:FT``#P\P,`J@'D1_GVTP"1E.)'^2(`0/GB
M'P#Y`@"`TN$#%JK@`Q6JK___E^```+5@YD?YX1]`^0``0/D@``#*0`$`M-G^
M_Y>!`D#YX#>`N2`,`(L!!$#Y`0``^2'^_[0`(`"1_/__%_-30:GU6T*I_7O$
MJ,`#7];]>[JI_0,`D?-3`:FT``#P]5L"J?8#`*KU`P&J@.9'^?=C`ZGY:P2I
M`0!`^>$O`/D!`(#2H`)`.1_T`'%!``!4M08`D>`#%:JV_O^7X5,!D?<#`*K@
M`Q:JA?__E_,#`*H``@"TK_[_EQ\`%^MC!@!4``"`TJ%J8#AA:B`X``0`D:'_
M_S4``(!2E.9'^>(O0/F!`D#Y00`!RJ$)`+2E_O^7LP``\&#B1_D9`$#Y``"`
MTB(C`-'X`P`J``0`D4%X8/BA__^UP0``D``+`!$BL$"Y`'Q]DR(!`#3A`P"J
MX`,9JK#]_Y=AXD?Y(```^:`!`+4``(`2Y?__%R(`@%(BL`"YZ/W_E_H#`*I`
M__^T`G]]D^$#&:KG_?^78.)'^1H``/ESXD?Y`']`DP`$`)%A`D#Y/W@@^/A7
M`+G@`Q:J`0!`.3_T`'$D&$!ZH0,`5+,``/#X5X"Y```6R_<*`)%SXD?Y&/-]
MT^#"((MY`D#YS?W_ER!K./C@^_^TX5>`N6`"0/D`>&'XX0,`JL(60#@B%``X
M8@``-%_T`'%A`0!4H@>`4@(``#D``(#2HFI@.")H(#@`!`"1HO__-;/__Q<`
M!`"1W___%^`#`:KO__\7\U-!J?5;0JGW8T.I^6M$J?U[QJC``U_6_7NRJ?T#
M`)'S4P&IM```\('F1_GU6P*I]V,#J?EK!*DB`$#YXF\`^0(`@-)@`@"T`0!`
M.?4#`*H!`@`T5/W_E_<#`*J@`0"T&```T!D``-`8=S&1.7,QD?IC`9'@`Q>J
M?_W_EV`!`+7@`Q>JJ/W_E^`#%:H"_O^7E.9'^>%O0/F``D#Y(```RF`%`+0P
M_O^7$TP`D>$#&*K@`Q.J;/W_E^#]_S3A`QFJX`,3JFC]_Y=@_?\TX`,5JB'^
M_Y?V`P"JX`,3JA[^_Y<``!8+``@`$0!\0)-Z_?^7XP,3JN(#%:KV`P"J`0``
MT"%\,9$$_O^7X0,:JN`#%JKQ_?^7'P0`,4`!`%3@:T"Y``P4$A\00''!``!4
MX`,6JKK__Y?@`Q:JX_W_E\[__Q?@`Q:J8/W_E_O__Q?S4T&I]5M"J?=C0ZGY
M:T2I_7O.J,`#7];]>[6I_0,`D?-3`:FS``#P]`,`JF'F1_DB`$#YXE<`^0(`
M@-+AHP"18OW_ET`"`#7A.T"Y`@"44B$,%!(_$$!Q)!!">L$``%1!`(!2X`,4
MJA#]_Y<?``!QX!>?&G/F1_GB5T#Y80)`^4$``<J!``"TY/W_EP``@%+Y__\7
M\U-!J?U[RZC``U_6_7N_J:```/#]`P"1`-Q'^0``0+G!_?^7H@``\`,``-#]
M>\&H8\`PD4+T1_D!``#0(90QD;']_Q?]>[ZI_0,`D?,+`/FS``#P<]Y'^6`"
M0+FR_?^7Z___EV`"0+FO_?^7\PM`^00``-#]>\*HA,0[D04`@%+C`P2J`@``
ML`$``-!"H!"1(00RD>C\_Q<0"H32_V,PR_U[`*G]`P"1]5L"J;8``/#`YD?Y
M\U,!J?3C`)$!`$#YX2<0^0$`@-+K_/^7XP,`*@0``-`"``#0A%@RD4)H,I$A
M`(+2X`,4JL_\_Y<?!``Q(0$`5`,`@-+!YD?YX`,#JN(G4/DA`$#Y00`!RB$%
M`+2=_?^7`7Q`DS\$0/%)``!4`'T@U(#^_S<`"(+2\V,@BP(`@M+A`Q.JX`,4
MJB[]_Y?U`P"J@/W_-P`$`!$`?$"3Z?S_E^,#`*K@_/^TM'Y`DQ\`$^N"``!4
M```4BW\"`.N#_?]4?P`3ZXD``%1@`A2+?P``Z^/\_U0@`()2OP(`:XS\_U3@
M`P.JX@,4JN$#$ZII_?^7XP,`JA]H-#C3__\7$`J$TOU[0*GS4T&I]5M"J?]C
M,(O``U_6M/__%Q`>@M+_8S#+_7L`J?T#`)'S4P&IM```\/,#`:KU6P*I]0,`
MJH#F1_GW8P.I^6L$J?LK`/D!`$#YX7<(^0$`@-(```#0`)@RD5K^_Y?Z`P"J
MX06`4N`#%:K@_/^7@`$`M````-#A`Q6J`+PRD8?^_Y>4YD?YX`,5JN)W2/F!
M`D#Y00`!RD$)`+1,_?^7X`,5JD;]_Y<6``#0^P,`*L'R,I'@`Q.J&```T"C]
M_Y<9``#0\P,`JAAW,9$Y^S*1]Z,#D1/]_[1@`D`Y'P``<7,2F)I:`0"TX0,3
MJN`#&JIW_/^7P```-<'R,I$``(#2%_W_E_,#`*KS__\7X`,3JBO]_Y=APB"+
M(?!?.#^\`'$@`@!480<`$2````L?_#]Q+/K_5.4#%:KD`QFJXP,3J@(``-`!
M`(+20F@VD>`#%ZI'_/^7``0`$1\$0'&I``!4`'T@U``$`%%_RB`XZO__%^&C
M`9'@`Q>J\?S_E^#[_S7@>T"Y``P4$A\@0'%A^_]4(0"`4N`#%ZHQ_/^7X/K_
M->$#%ZH```#0`+PRD3S^_Y?@`Q>J>OS_E_4#`*JR__\7$!Z"TOU[0*GS4T&I
M]5M"J?=C0ZGY:T2I^RM`^?]C,(O``U_6X0,`J@(`0#EB```UX`,!JL`#7]8`
M!`"17[P`<2$0@)KY__\7H`<`M/U[OJG]`P"1\PL`^?,#`*H!`$`YP0``-0``
M`-``=#&1\PM`^?U[PJA:_/\7X?S_EP($`-%B`@*+?P("ZV(#`%1``$`Y'[P`
M<6`"`%3@`P*J`?1?.#^\`'$A`@!40@0`T7\"`NN"``!40`!`.1^\`'%@__]4
M0@`3RT`(`)$?!$#Q2`,`5$($`)%?!$#QZ0$`5`!](-1"!`#1Z/__%^(#`*I_
M`@#K0_W_5'\"`NN!_?]48`)`.1^\`'$`^_]4````T`#X,I'7__\7PP``D&-`
M`Y'A`Q.JX`,#JEK\_Y?S"T#Y_7O"J,`#7]8``(#2_/__%P```-``=#&1S/__
M%_U[N:G]`P"1\U,!J;,``/`4``#08.9'^?5;`JD6``#0]QL`^1<``-`5``#0
MM1XTD0$`0/GA-P#Y`0"`T@```-``P#"1`"@`D0(,0*GB#P2I`@Q!J>(/!:D`
M0$!YX,,`>0```-```#.1I_W_EP```-``)#.1I/W_EP```-``1#.1H?W_EP``
M`-``:#.1GOW_E\"&,Y&<_?^7````T`#$,Y&9_?^7X)HRD9?]_Y>`]C.1E?W_
ME^`#%:J3_?^7````T`!$-)&0_?^7````T`"\,I&-_?^7````T`!L-)%X_?^7
M@```M.$#`*K@`Q6JJOW_EP```-``L#21<?W_EZ```+3A`P"J````T`#X-)&B
M_?^7````T``D-9%I_?^7P`$`M.$#`*K@FC*1F_W_EP$``-#`AC.1(=0UD9?]
M_Y=SYD?YX3=`^6`"0/D@``#*0`(`M%W\_Y<```#0`&0UD5C]_Y>```"TX0,`
MJH#V,Y'O__\7`0``T/4#`9%"`8#2(:@UD>!'`9&T^_^7(/W_-:%N`)'V__\7
M\U-!J?5;0JGW&T#Y_7O'J,`#7];]>[ZI_0,`D?,+`/G3``"08`I`N1\$`#%!
M`0!4````T`#T,Y$\_?^70`$`M```0#D``0`T'\``<>`'GQI@"@"Y8`I`N?,+
M0/G]>\*HP`-?U@``@%+Z__\7_7N_J?T#`)$S_/^7OOO_ET```+0``$#Y_7O!
MJ,`#7];]>[VI_0,`D?5;`JD5``#0MMXUD?-3`:GS`P"JX`,6JA_]_Y>```"T
M`0!`.?0#`*KA```UX0,3JJ#>-9'S4T&I]5M"J?U[PZA+_?\7X0,3JI'[_Y>`
M`@"UX`,3J@[\_Y?U`P"JX`,4J@O\_Y>@`@"+``@`D6C[_Y?D`Q2J]0,`J@,`
M`-#B`Q.J8_`RD0$``-`A:#:1\/O_E^$#%:K@`Q:JY___%_-30:GU6T*I_7O#
MJ,`#7]80-)#2_V,PRP("D-+A8R*+_7L`J?T#`)'W8P.IMP``\!@``-#Y:P2I
M^0,`JN#F1_GS4P&I]5L"J?LK`/D"`$#Y(L0`^0(`@-+```"0`"``D0*,0*GB
M#P>I`@Q"J>(/"JD"#$.IX@\+J0(,1*GB#PRI`@Q%J>*/"*D!#$#YX4,`^0`P
M0/G@3P#Y`)LRD=?\_Y<@`@"T`0!`.?,#`*K!`0`TJ___E^`#$ZI&^_^7\P,`
MJO?F1_D!`I#2X6,AB^`#$ZHBQ$#YX0)`^4$``<K!)P"TR/O_EY;__Y?S`P"J
M``(`M?0C`I&``D#Y@```M1,``-!S'C:1"@``%+S\_Y=@``"UE"(`D?C__Q<!
M`$`YH?__-"S[_Y?S`P"J0/__M.`#$ZJP^_^7`/A_TQ4``-``!`"1M3HVD0O[
M_Y?Z`P"J]`,`JF("0#F"!P`U\X,"D78"0/F6`0"TX`,6JJ3\_Y?T`P"J8`<`
MM`$`0#DA!P`TH?W_E^`&`#3@`Q2J$OO_E_8#`*KTPP&1M@``M9,"0/ES``"T
M8`)`.0`&`#7@`Q:JD?O_E_,#`*K@`QJJCOO_EQ,`$PMS$A`1%```T'-^0)/@
M`Q.JZ/K_E^4#&JJ#^C*1X@,6J@0``+"$3#:1]0,`J@$``+`A8#:1;_O_EP$X
M@%+@`Q6J5/O_EQ\$`#'A`P!43?O_EP0`0+F?1`!Q8`,`5*```-`!``"P(@-`
M^>,#%:H`Q$?Y(80VD0``0/DF^_^7$P"`TJ#__Q?@`Q2JX0,5JG,&`)%8^_^7
ME`H`D;[__Q=S(@"1O___%^`#$ZIF_?^7@```-.`#$ZK7^O^7]@,`JI0B`)'%
M__\7X4,#D>`#%:K)^O^7^@,`*D`!`#2@``#0XP,5JB(#0/D!``"P`,1'^2%P
M-Y$``$#Y!_O_E^'__Q?@XT"Y``P4$A\00'&!_O]4]NM`N5#[_Y??`@!K`?[_
M5.#C0+D`(``2'P`'<8']_U3@`Q.JH/K_E_,#`*H```"P``@VD3[\_Y=@"P"U
M-@-`^>`#%JHX^_^7^P,`JA\,`'&-`P!4`'Q`DP$``+``$`#1(;PXD<`"`(MS
M^O^7H`(`-7\3`''```!4>Q,`4=O".XM@\U\X'[P`<<$!`%0Y!T#YF0$`M.`#
M&:HC^_^7'PP`\0D!`%0`$`#1`0``L"`#`(LAT#B18/K_EQ\``''6$IF:UO[_
MET`-`#7@`Q:J`0"`4I'Z_Y?V`P`JH`P`-$(`@%(A`H"2^6,&D4OZ_Y?"`(#2
MX0,9JN`#%BK3^O^7X&-&.2`&`#7@9T8Y'PP!<<$%`%3@:T8Y'P0!<6$%`%3@
M;T8Y'PP!<0$%`%3@<T8Y'R`!<:$$`%3@=T8Y'Q0!<4$$`%1"`(!2(0>`DN`#
M%BHR^O^7(@6`TN$#&:K@`Q8JNOK_EP4``+#D`QFJI<0[D0$``+"#^C*1X@,5
MJB'D.)'@`Q.JV?K_E^`#%:K#^O^7X0,3J@";,I$<_/^7X`,3JKW^_Y<5__\7
M-@-`^5?Z_Y?A`P"JX`,6JG+]_Y?V`P"J(/3_M9___Q<"`(!2`0"`TN`#%BH1
M^O^7?`4`E/H#`*H"`)#2X0,9JN`#%BJ7^O^7'P``<4P#`%3@`Q8J^T,%D8KZ
M_Y?YHP61X0,:JN`#&ZKA!0"4&@``L.0#&:I:.S:1%@"`TF)K=CC@`QFJX0,:
MJM8&`)'D-P#Y.0L`D:OZ_Y??4@#QY#=`^>'^_U0%``"PI<0[D?]#!CG&__\7
MX@,`*N$#&:K@`QJJ;P4`E-W__Q<!``"P(=0UD1D``+`Y6SF1````L`#T,Y'@
M^_^7%@``L.;Y_Y?6QCN1E/HRD>0#`"KE`Q:JXP,4JN(#%:H!``"PX`,3JB$@
M.9&,^O^7`3B`4N`#$ZIQ^O^7'P0`,>'U_U1J^O^7``!`N1]$`'%A]?]4TOG_
MEUH'`!'D`P`JY@,6JN4#&BKC`Q2JX@,5JN$#&:K@`Q.J>?K_E^W__Q<0-)#2
M_7M`J?-30:GU6T*I]V-#J?EK1*G[*T#Y_V,PB\`#7];]>[JI_0,`D?-3`:FS
M``#0=-Y'^?5;`JGW8P.I^6L$J?MS!:F``D"Y8/K_E_4#`*J``D"Y7?K_EZ'B
M0CD!Y`(Y````L`"$,Y%N^_^7P```M`$`0#D_Q`!Q80``5``$0#E````TN/W_
MEW;>1_FT``#PP`)`N4WZ_Y<!``"P8P&`4B(`@%(AG#F1Y/G_ER`$`+5VWD?Y
MP`)`N43Z_Y=C`(!2(@"`4@$``+`AL#F1V_G_E_4#`*H`"@"U=MY'^<`"0+DZ
M^O^78P"`4B(`@%(!``"P(<PYD='Y_Y?U`P"J0`P`M````+``O#*11OO_E_<#
M`*I`"@"TP`)`N2SZ_Y>A"D#YX@,7JB$`0/G,^?^75@``%``(0/D:@(!2F<("
MD34`@%(:!*!R&Q1`^;@&`%$A!T"YP`)`N3\`%6L-`0!4&_K_EP,`@%("?T"3
MX0,;JGOY_Y?W`P"J0`$`M8#"`I$!!$"Y(00`43\`&&M!^?]4-@"`4O4#`*IW
MWD?Y&@``%`$`0/D@!T#Y'-AU^"`,0+D``!H*'P`0<0$!`%0@"$#YX0,`JN`#
M'*I9^?^7@/W_-;4&`!'>__\7P`)`N?SY_Y?A`D#Y0P"`4@(`@-((^O^7]/__
M%]8&`!'U^?^7X0,;JA_Y_Y>A!D"YX`)`N3\`%FLL__]4J/__%\`"0+GL^?^7
MH0I`^0(``+!"N#F1(0!`^8OY_Y>@"D#Y``!`^0`,0+G@]+<VP`)`N>'Y_Y>A
M"D#Y(0!`^4KY_Y>A__\7.?S_E_<#`*K``D"Y]P0`M-CY_Y>A"D#YX@,7JB$`
M0/EX^?^7X`,7JL+Y_Y=SWD?Y8`)`N<_Y_Y?U`P"J8`)`N<SY_Y<B`(!2`0``
ML"'4.9$`^?^7`@``L.$#`*I"*#J1X`,5JF?Y_Y=@`D"YD\("D<#Y_Y<?Y`(Y
M````L`"8,I'2^O^78`H`^<`!`+5@!D#YU/W_EV`*`/E``0"U````L`!`.I'[
M^/^7LOG_EX'"`I$B!$#YH0I`^4(`0/F$__\7E,("D0$X@%*`"D#YE?G_EQ]$
M`'%``0!4`00`$3\$`''I``!4@8I`J>,#`"H```"P`,0ZD2$`0/GF^/^7\U-!
MJ?5;0JGW8T.I^6M$J?MS1:G]>\:HP`-?UOU[OJG]`P"1\U,!J?,#`*JY_/^7
MK_S_E_0#`*I@_?^7P`$`-+,!`+1@`D`Y8`$`-`$``+#@`Q2J(4PVD1OY_Y>?
M`@#KH0``5.`#$ZKS4T&I_7O"J$;[_Q?S4T&I_7O"J,`#7];_@PK1I0``T.-C
M`)$&X`"1".`!D><#`ZK]>P"I_0,`D:'D1_DB`$#YXD\!^0(`@-+!`$"YYT``
MD<2$0/@A",!:X0`?^-\`".N!_&#3(AP(4R'<>-,A''"200`!JH+\:--"''B2
M1.!$JB$`!*KA@!_X`?[_5`0(@%)B($#YA`0`<6$T0/EC(`"19H!?^"(``LIA
M!$#Y(0`&RD$``<HB_%_3000!JB%\0))A/`#Y8?[_5`<80*DK,X_2""1!J4M0
MJ_(*$$#YX?Q;T^S\0M,A%`>JC'D'JB(!",J0?4"20@`&BD(`"<I!0"&+XI-!
MJ4(`"XN$``N+(0`"B\+\0M-">`:J(0`*"TY\0))-``S*PP$(RJT!`8IC``>*
MK0$.RF,`",JM`0B+8P`)BV0`!(LC_%O38Q0!JF,`!`LD_$+3A'@!JN*'0JF,
M`03*C`$#BH]\0)*,`1#*C`$.BT(`"XLA``N+K0$"BV+\6]-"%`.JC`$!BT(`
M#0M!_%O3(10"JB$`#`ML_$+3@WD#JDS\0M..``/*<7Q`DLX!`HJ">0*J;0`"
MRLX!#\KDCT.IS@$0BZT!`8HL_$+3K0$1RE!\0)*M`0^+A``+BV,`"XO.`02+
M)/Q;TX04`:J!>0&JA``."ZT!`XM,``'*+WQ`DH/\6].,`02*XB=`^6,4!*IC
M``T+C`$0RD(`"XN,`1&+C`$"BV+\6]-"%`.J0@`,"XS\0M.$>02J;/Q"TRX`
M!,J1?$"2S@$#BH-Y`ZJ-``/*S@$/RN$31:G.`1"+K0$"BDS\0M.M`1'*<'Q`
MDJT!#XLA``N+A``+B\X!`8M!_%O3(10"JH)Y`JHA``X+K0$$BVP``LI/?$"2
M)/Q;TXP!`8KC,T#YA!0!JH0`#0N,`1#*8P`+BXP!$8N,`0.+@_Q;TV,4!*IC
M``P++/Q"TX%Y`:J,_$+33@`!RC%\0)+.`02*A'D$JBT`!,K.`0_*XH=&J<X!
M$(NM`0.*;/Q"TZT!$<J0?$"2K0$/BT(`"XLA``N+S@$"BV+\6]-"%`.J@WD#
MJD(`#@NM`0&+C``#RF]\0))!_%O3C`$"BN0_0/DA%`*J(0`-"XP!$,J$``N+
MC`$1BXP!!(LD_%O3A!0!JH0`#`M,_$+3@GD"JFX``LI1?$"2XT-`^<X!`8K.
M`0_*8P`+B\X!$(O.`0.+@_Q;TV,4!*IN``X+(_Q"TV%X`:I-``'*,'Q`DN)'
M0/FM`02*K0$1RL/]0M-"``N+K0$/BZT!`HO"_5O30A0.JF-X#JI-``T+@OQ"
MTT1X!*HL``3*CWQ`DN%+0/F,`0Z*C`$0RH0``\HA``N+C`$1BXP!`8NA_5O3
M(10-JH0`#8HL``P+A``/RN%/0/F$`!"+HOU"TVY\0)(A``N+0G@-JH0``8N!
M_5O3(10,JF,``LHD``0+8P`,BN%30/EC``[*8P`/BTU\0)(A``N+8P`!BX'\
M6],A%`2J(P`#"X']0M,A>`RJ0@`!RB]\0)+L5T#Y0@`$BD(`#<J,`0N+0@`.
MBT(`#(ML_%O3C!4#JD)`+(N,_$+3A'D$JDY\0)(A``3*[%M`^2$``XHA``_*
MBP$+BR$`#8LA``N+R_U;TVL5#JHA0"N+:_Q"TV-Y`ZHP?$"2C``#RBMTG=*,
M`0)**]NM\N)?0/F,`0^+#?Y;TT(`"XNM%1"JC`$"B\+]0M-">`ZJC$$MBVT`
M`LJ1?4"2H0$!2B1`)(LM_EO3X6-`^:T5$:HA``N+A``!BP'^0M,A>!"JA$`M
MBTT``<J/?$"2K`$,2H-!(XOM_5O3[&=`^:T5#ZJ,`0N+8P`,BRS^0M.,>1&J
M8T`MBRT`#,IN?$"2I`$$2H)`(HO-_5O3Y&M`^:T5#JJ$``N+0@`$B^3]0M.$
M>`^J0D`MBXT!!,I0?$"2HP$#2F%`(8L-_EO3XV]`^:T5$*IC``N+(0`#B\/]
M0M-C>`ZJ(4`MBXT``\HO?$"2H@$"2DQ`+(OM_5O3XG-`^:T5#ZI"``N+C`$"
MBP+^0M-">!"JC$$MBVT``LJ.?4"2H0$!2B1`)(O-_5O3X7=`^:T5#JHA``N+
MA``!B^']0M,A>`^JA$`MBTT``<J0?$"2K`$,2H-!(XL-_EO3['M`^:T5$*J,
M`0N+8P`,B\S]0M.,>0ZJ8T`MBRT`#,IO?$"2I`$$2H)`(HOM_5O3Y']`^:T5
M#ZJ$``N+0@`$BP3^0M.$>!"J0D`MBXT!!,I.?$"2HP$#2F%`(8O-_5O3XX-`
M^:T5#JIC``N+(0`#B^/]0M-C>`^J(4`MBXT``\HP?$"2H@$"2DQ`+(L-_EO3
MXH=`^:T5$*I"``N+C`$"B\+]0M-">`ZJC$$MBVT``LJ/?4"2H0$!2B1`)(OM
M_5O3X8M`^:T5#ZHA``N+A``!BP'^0M,A>!"JA$`MBTT``<J.?$"2K`$,2H-!
M(XO-_5O3[(]`^:T5#JJ,`0N+8P`,B^S]0M.,>0^J8T`MBRT`#,IP?$"2I`$$
M2H)`(HL-_EO3Y)-`^:T5$*J$``N+0@`$B\3]0M.$>`ZJ0D`MBXX!!,I-?$"2
MPP$#2F%`(8NN_5O3XY=`^<X5#:IC``N+(0`#BP/^0M-C>!"J(4`NBXX``\HO
M?$"2P@$"2DQ`+(ON_5O3XIM`^<X5#ZI"``N+C`$"BXQ!+HNN_4+3S7D-JH)]
M0))N``W*P0$!2D[\6],D0"2+SA4"JN&?0/DA``N+A``!B^']0M,A>`^JA$`N
MBZ\!`<J.?$"2[`$,2H-!(XO/_5O3[*-`^>\5#JJ,`0N+8P`,BTS\0M.0>0*J
MS/U"TR(`$,J,>0ZJ1``$2F]`+XN-0"V+!`(,RN-]0)*/``]*XI-4J>%!(8M"
M``N+BP`+BZT!`HMD_$+38OQ;TRL`"XM"%`.J@W@#JD(`#0MO?$"2C7U`DHP!
M`ZJD`0^*C`$"BD'\6].,`02JY*]`^2$4`JHA``L+BYN7TFOCL?*,03"+A``+
MBXP!!(LD_%O3A!0!JHP`#`M$_$+3@G@"JB3\0M-1?$"2;@`"JLX!`8KC`1&*
M@7@!JLX!`ZHP?$"2S@$-BTT``:HB`A"*K0$,BH3]0M.M`0*JA'@,JN,+5JFM
M`0^+CWQ`DF,`"XM"``N+S@$#BX/]6]-C%`RJ+``$JF,`#@L!`@^*C`$#BJT!
M`HN,`0&J8OQ;T^&[0/E"%`.J0@`-"XP!$8LA``N+C`$!BT'\6],A%`*J(0`,
M"VS\0M.#>0.J3/Q"TW%\0)*.``.JS@$"BN0!$8J">0*JS@$$JFT``JK.`1"+
M4'Q`DJT!`8HC`A"*+/Q"TZT!`ZKDCU>IK0$/BX0`"XMC``N+S@$$BR3\6].$
M%`&J@7D!JH0`#@LO?$"23``!J@("#XJ,`02*K0$#BXP!`JJ#_%O3XL=`^6,4
M!*IC``T+C`$1BT(`"XN,`0*+8OQ;TT(4`ZI"``P+C/Q"TX1Y!*IL_$+3D7Q`
MDBX`!*K.`0.*X0$1BH-Y`ZK.`0&JC0`#JLX!$(MP?$"2K0$"BB0"$(I,_$+3
MK0$$JN$36:FM`0^+(0`+BX0`"XO.`0&+0?Q;TR$4`JJ">0*J(0`."T]\0))L
M``*J`P(/BHP!`8JM`02+C`$#JB3\6]/CTT#YA!0!JH0`#0N,`1&+8P`+BXP!
M`XN#_%O38Q0$JF,`#`LL_$+3@7D!JHS\0M,Q?$"23@`!JLX!!(KB`1&*A'D$
MJLX!`JHM``2JS@$0BY!\0)*M`0.*(0(0BFS\0M.M`0&JXH=:J:T!#XM"``N+
M(0`+B\X!`HMB_%O30A0#JH-Y`ZI"``X+;WQ`DHP``ZH$`@^*C`$"BJT!`8N,
M`02J0?Q;T^3?0/DA%`*J(0`-"XP!$8N$``N+C`$$BR3\6].$%`&JA``,"TS\
M0M.">0*J47Q`DFX``JK.`0&*XP$1BLX!`ZKCXT#YS@$0BV,`"XO.`0.+@_Q;
MTV,4!*IN``X+(_Q"TV%X`:HP?$"230`!JJT!!(HB`A"*K0$"JL/]0M/BYT#Y
MK0$/BV-X#JI"``N+K0$"B\+]6]-"%`ZJ30`-"X+\0M-$>`2JCWQ`DBP`!*J,
M`0Z*`0(/BHP!`:IN?$"2X>M`^8P!$8N$``.JHOU"TR$`"XN$``V*C`$!BZ']
M6],A%`VJ0G@-JBP`#`OA`0Z*A``!JDU\0)+A[T#YA``0BV,``JHA``N+8P`,
MBH0``8N!_5O3(10,JB0`!`O!`0V*8P`!JN'S0/EC``^+C_Q;TR$`"XOO%02J
M8P`!BX']0M,A>`RJXP$#"RQ\0))"``&JKP$,BD(`!(I"``^J0@`.B^[W0/G.
M`0N+0@`.BV[\6]/.%0.J3D`NBX+\0M-$>`2JT7U`DI!\0)(A``2J@@$0BB$`
M`XHA``*JXOM`^2$`#8LM_EO32P`+BZT5$:HA``N+8OQ"TRU`+8M/>`.JJWU`
MDH(`#\KA_T#Y0@`.2L0ZF-)N_5O31$RY\D(`#(LA``2+SA4+JD(``8LC_D+3
M3D`NBV-X$:K,?4"2X0$#RN(#0?DA``U*C?U;TR$`$(NM%0RJ0@`$BR$``HMB
M_4+3(4`MBTMX"ZKM!T'Y8@`+RC!\0))"``Y*K0$$BT)`+XM"``V+#?Y;TZT5
M$*JEY$?Y0D`MBXW]0M-/?$"2K'D,JFT!#,JA`0%*[?U;TR-`(XNM%0^JX0M!
M^2$`!(MC``&+`?Y"TR%X$*IC0"V+C0$!RFY\0)*B`0)*2T`KB\W]6]/B#T'Y
MK14.JD(`!(MK`0*+XOU"TT)X#ZIK02V++0`"RG!]0)*C`0-*;$`LBPW^6]/C
M$T'YK140JF,`!(N,`0.+P_U"TV-X#JJ,02V+30`#RH]]0)*K`0M*84$AB^W]
M6]/K%T'YK14/JFL!!(LA``N+"_Y"TVMY$*HA0"V+;0`+RBY\0)*L`0Q*@D$B
MB\W]6]/L&T'YK14.JHP!!(M"``R+[/U"TXQY#ZI"0"V+;0$,RE%\0)*A`0%*
M(T`CBRW^6]/A'T'YK141JB$`!(MC``&+P?U"TR%X#JIC0"V+C0$!RG!\0)*B
M`0)*2T`KBPW^6]/B(T'YK140JD(`!(MK`0*+(OY"TT)X$:IK02V++0`"RF]]
M0)*C`0-*;$`LB^W]6]/C)T'YK14/JF,`!(N,`0.+`_Y"TV-X$*J,02V+3@`#
MRHU]0)++`0M*84$ABZ[]6]/K*T'YSA4-JFL!!(LA``N+Z_U"TVMY#ZHA0"Z+
M;@`+RC%\0)+,`0Q*@D$BB^PO0?F,`02+0@`,BRS^6].,%1&J0D`LBZS]0M.-
M>0VJ4'Q`DFP!#<J!`0%*#OY;TR-`(XO.%1"JX3-!^2$`!(MC``&+(?Y"TR%X
M$:IN0"Z+K`$!RL-]0)*"`0)*2T`KBV_\6]/B-T'Y[Q4#JD(`!(MK`0*+`OY"
MTT)X$*IO02^++``"RNM]0)*.`0Y*[#M!^<U!+8MN_5O3C`$$B\X5"ZJM`0R+
M;/Q"TX-Y`ZJN02Z+3``#RLU]0)*/`0]*[#]!^>%!(8MO_4+3ZWD+JHP!!(MO
M``O*(0`,BZS]6]/N`0Y*C!4-JL)!(HON0T'Y+$`LBX%]0)*O_4+3S@$$B^UY
M#:I"``Z+;P$-RB[\6]/L`0Q*SA4!JH-!(XOL1T'Y3D`NB\)]0)*J`0H+C`$$
MBPH0`/EL``R+0_Q;TV,4`JIC``P++/Q"TX%Y`:I,_$+3@GD"JJP!`<J.`0Y*
M*0`)"^Q+0?G+02N+Q@`#"T@`"`N$`02+""0!J6L!!(MD_%O3A!0#JH0`"PN'
M``<+!Q@`J>%/0?F@`$#Y(```RD```+1@]?^7_7M`J?^#"I'``U_6_7N_J0`0
M@-+]`P"1M?3_EQ_\`JDB8(32HNBL\@(``/DB<972'W@`N:+YO?("!`#YPI^;
MTD(7L_(""`#YPHZ*TD(&HO("#`#Y`CZ<TD)ZN/("$`#Y_7O!J,`#7];]>[RI
M_0,`D?-3`:GS`P"J0'Q`D_5;`JGU`P"J8A9`^?<;`/E##``+7P`#ZXD``%1B
M&D#Y0@0`D6(:`/EB&D#Y=.(`D4!T0(MC@@*I8'I`N8`#`#06"(!2U@(`2[\"
M%FN`PB"+MM*6&A\``>O"?D"3H@``5`,``HL_``/K0@``5`!](-0W``*+'P`!
MZVD``%0?`!?K8___5`_U_Y=@>D"YP`(`"V!Z`+D?``%Q@04`5.`#$ZJ#^_^7
MM0(62^$#%ZIWX@&1%@``%#\`%.MI``!4/P`7ZV/]_U0_`!3K-@`!D6(``%2?
M`A;KP_S_5"(,0*F"#@"IM0(!42(,0:F"#@&I(@Q"J8(.`JD@!$.I@`8#J>`#
M$ZIK^_^7X0,6JK_^`'%,_?]4HGY`DS\`%.N)``!4@`("BS\``.M#^O]4/P`4
MZX(``%0@``*+GP(`ZZ/Y_U3@`Q2JX/3_EW5Z`+GS4T&I]5M"J?<;0/G]>\2H
MP`-?UOU[O*G]`P"1\U,!J?0#`*KS`P&J]5L"J37@`)'W&P#Y(!1`^38H0+DW
M,$"YX0^`$@`@`U/6"L!:`@0`$?<*P%I?X`!QH<H@.*#"(HN-"0!4`0B`4B(`
M`DL!`(!20GQ`DR'T_Y?@`Q.J.OO_EW_^`ZE__@2I?_X%J7\V`/EW6@XIX`,3
MJC/[_Y=@`D#Y`/Q8TX`"`#E@`D#Y`/Q0TX`&`#E@`D#Y`/Q(TX`*`#E@`D#Y
M@`X`.6`&0/D`_%C3@!(`.6`&0/D`_%#3@!8`.6`&0/D`_$C3@!H`.6`&0/F`
M'@`Y8`I`^0#\6-.`(@`Y8`I`^0#\4-.`)@`Y8`I`^0#\2-.`*@`Y8`I`^8`N
M`#E@#D#Y`/Q8TX`R`#E@#D#Y`/Q0TX`V`#E@#D#Y`/Q(TX`Z`#E@#D#Y@#X`
M.6`20/D`_%C3@$(`.6`20/GU6T*I`/Q0TX!&`#E@$D#Y`/Q(TX!*`#E@$D#Y
M@$X`.>`#$ZKS4T&I]QM`^?U[Q*AC]/\7`0>`4B(``DL!`(!20GQ`D];S_Y>[
M__\7_7N_J?T#`)']>\&HP`-?UG!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@(```+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$
M>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E
M<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`
M4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'
M`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%4
M2`!365-414T`)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`)7,Z
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E
M;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!P87)L`"YP87(`
M)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S
M`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-#D`56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@`M90`M+0!54T52`%5315).04U%`%1%35!$25(`5$U0`"]T;7``979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R
M7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R
M7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&
M2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU
M;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE
M(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H
M;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O
M<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M
M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E
M:RA?1D@L("1M86=I8U]P;W,L(#`I.PIR96%D*%]&2"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RDI.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@
M)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T
M(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L
M(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U
M*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1I;F9O+3Y[8G5F?3L*<V5E:R@D9F@L(#`L
M(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M
M<&9I;&4H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@
M;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I
M;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@
M>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I
M;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@
M('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*
M;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@
M)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O
M=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET
M92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*
M96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E
M<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#
M86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C
M86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN
M:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P
M87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD
M("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&
M:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@
M)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB
M:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL
M97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@
M/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS
M965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]
M"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]
M("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L
M(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K
M97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T
M("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A
M8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O
M<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF
M("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M
M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=
M*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N
M)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`]
M(#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*
M)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI
M.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#
M04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP
M<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E
M;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*
M9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@
M+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60[
M"F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H
M)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D[
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H
M;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD
M8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE
M>&1I9V5S=#L*?2`O+R`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E
M*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL
M97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M
M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A
M;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@
M)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@`!&P,[]````!T```#8E/__+`4``/B6__\,`0``))?__R`!``!<E___-`$`
M`,27__]8`0``])?__W@!``"PF/__K`$``/B8___0`0``B)G___P!``!LF___
M.`(``+B<__]T`@``0)W__YP"``!XG?__O`(``,R=___@`@``_)[__Q0#````
MG___*`,``-"@__]T`P``]*#__X@#``#TH?__Q`,``)RC___T`P``]*/__Q@$
M```4I/__.`0``,BD__]P!```L*K__[P$````KO___`0``&2N__]8!0``2+__
M_WP%``"DO___G`4``!3!___,!0```````!```````````7I2``1X'@$;#!\`
M$````!@```#DE?__+``````````0````+````/R5__\X`````````"````!`
M````();__V@`````1`X@G02>`T*3`E+>W=,.`````!P```!D````9);__S``
M````1`X0G0*>`4?>W0X`````,````(0```!TEO__O`````!!#D"=")X'1),&
ME`65!)8#EP*8`6,*WMW7V-76T]0.`$$+`"````"X````_);__T@`````00XP
MG0:>!4*3!$[>W=,.`````"@```#<````()?__Y``````00Y`G0B>!T*5!)8#
M0Y,&E`5=WMW5UM/4#@``.`````@!``"$E___Y`$```!!#F"=#)X+0I,*E`E"
ME0B6!T67!I@%F02:`P)NWMW9VM?8U=;3U`X`````.````$0!```LF?__3`$`
M``!!#N`!G1R>&T*3&I091948EA>7%I@5F12:$P)*WMW9VM?8U=;3U`X`````
M)````(`!```\FO__B`````!!#K`!G1:>%4*3%)037M[=T]0.`````!P```"H
M`0``G)K__S@`````00X0G0*>`4C>W0X`````(````,@!``"TFO__5`````!!
M#B"=!)X#0I,"2M[=TPX`````,````.P!``#DFO__,`$```!"#M!`09V*")Z)
M"$*5A@B6A0A#DX@(E(<(`D/=WM76T]0.`!`````@`@``X)O__P0`````````
M2````#0"``#0F___T`$```!"#O`A09V>!)Z=!$*3G`24FP1#E9H$EID$19>8
M!)B7!)F6!)J5!)N4!`)FW=[;V=K7V-76T]0.`````!````"``@``5)W__R0`
M````````.````)0"``!DG?__``$```!"#B"=!)X#0I,"1][=TPX`00X@DP*=
M!)X#;@K>W=,.`$$+0@X`T]W>````+````-`"```HGO__J`$```!!#G"=#IX-
M0I,,E`M$E0J6"4*7"`)@WMW7U=;3U`X`(``````#``"@G___6`````!!#B"=
M!)X#0I,"4`K>W=,.`$$+'````"0#``#4G___(`````!!#A"=`IX!1M[=#@``
M```T````1`,``-2?__^T`````$$.,)T&G@5"E0*6`4.3!)0#3`K>W=76T]0.
M`$$+6=[=U=;3U`X``$@```!\`P``4*#__^@%````0@Z@@P)#G;0@GK,@0I>N
M()BM($.9K"":JR!%D[(@E+$@E;`@EJ\@FZH@`VH!W=[;V=K7V-76T]0.```\
M````R`,``.RE__]0`P```$$.8)T,G@M"DPJ4"4:5")8'EP:8!9D$F@.;`IP!
M`LK>W=O<V=K7V-76T]0.````+`````@$``#\J/__9`````!!#B"=!)X#0I,"
ME`%2"M[=T]0.`$$+0M[=T]0.````*````#@$``"DC___U`$```!!#E"="IX)
M0I,(E`=#E08":0K>W=73U`X`00L@````9`0```2I___D$````$$.H`5&G52>
M4P,Q!-W>#@`````<````B`0``,2Y__]<`````$$.$)T"G@%5WMT.`````"P`
M``"H!````+K__W`!````00Y`G0B>!T*3!I0%0Y4$E@-#EP("4M[=U]76T]0.
M`#````#8!```0+O__Y0!````00Y`G0B>!T*3!I0%0Y4$E@-"EP("5@K>W=?5
MUM/4#@!!"P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#PA````````U"`````````!
M``````````$``````````0````````#9`@````````\`````````@00`````
M```,`````````#@:````````#0`````````@3````````!D`````````@)L!
M```````;``````````@`````````&@````````"(FP$``````!P`````````
M"`````````#U_O]O`````"`"````````!0`````````0#0````````8`````
M````"`,````````*`````````)\$````````"P`````````8`````````!4`
M```````````````````#`````````'"=`0```````@````````#0!0``````
M`!0`````````!P`````````7`````````&@4````````!P````````"P$0``
M``````@`````````N`(````````)`````````!@`````````&```````````
M`````````/O__V\``````0``"`````#Y__]O`````!``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````4!H```````!0&@```````%`:````````4!H```````!0&@``
M`````%`:````````4!H```````!0&@```````%`:````````4!H```````!0
M&@```````%`:````````4!H```````!0&@```````%`:````````4!H`````
M``!0&@```````%`:````````4!H```````!0&@```````%`:````````4!H`
M``````!0&@```````%`:````````4!H```````!0&@```````%`:````````
M4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````D)L!``````!0'@`````````````````````````````@3```
M```````````````````````````X&@``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P`````23P```````%U,````````````
M```````^30```````#=-````````!D\```````!430````````Y/````````
M``````````#X3@```````/U.```````````````````73P```````$=#0SH@
M*$%L<&EN92`X+C,N,"D@."XS+C```"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M``````````````````````````````````````````````L````!`````@``
M`````````@`````````"````````&@````````````````````$`````````
M```````````3````]O__;P(`````````(`(````````@`@```````.@`````
M`````P`````````(````````````````````'0````L````"``````````@#
M````````"`,````````("@````````0````#````"``````````8````````
M`"4````#`````@`````````0#0```````!`-````````GP0`````````````
M``````$````````````````````M````!`````(`````````L!$```````"P
M$0```````+@"`````````P`````````(`````````!@`````````-P````0`
M``!"`````````&@4````````:!0```````#0!0````````,````1````"```
M```````8`````````$$````!````!@`````````X&@```````#@:````````
M$`````````````````````0````````````````````\`````0````8`````
M````4!H```````!0&@`````````$```````````````````0`````````!``
M````````1P````$````&`````````%`>````````4!X```````#0+0``````
M````````````!````````````````````$T````!````!@`````````@3```
M`````"!,````````$`````````````````````0```````````````````!3
M`````0````(`````````,$P````````P3````````$@]````````````````
M```!````````````````````6P````$````"`````````'B)````````>(D`
M``````#T````````````````````!````````````````````&D````!````
M`@````````!PB@```````'"*````````#`4```````````````````@`````
M``````````````!S````#@````,`````````@)L!``````"`FP````````@`
M```````````````````(``````````@`````````?P````\````#````````
M`(B;`0``````B)L````````(````````````````````"``````````(````
M`````(L````&`````P````````"0FP$``````)";````````X`$````````$
M``````````@`````````$`````````"4`````0````,`````````<)T!````
M``!PG0```````)`"```````````````````(``````````@`````````F0``
M``$````#``````````"@`0```````*````````!X````````````````````
M"````````````````````)\````(`````P````````!XH`$``````'B@````
M````6!````````````````````@```````````````````"D`````0```#``
M``````````````````!XH````````!H````````````````````!````````
M``$``````````0````,`````````````````````````DJ````````"M````
<`````````````````0``````````````````````
